#!/usr/bin/env node

import { hideBin } from "yargs/helpers";
import yargs from "yargs";
import { join } from "path";
import yaml from "yaml";
import fs from "fs-extra";
import consola from "consola";

import print from "./command/print.js";
import init from "./command/init.js";
import schema from "./command/schema.js";
import add from "./command/add.js";
import cut from "./command/cut.js";
import upcoming from "./command/upcoming.js";
import latest from "./command/latest-version.js";

consola.raw = (...args) => console.log(...args);

yargs(hideBin(process.argv))
    .config({
        consola,
    })
    .default("source", join(process.cwd(), "CHANGELOG.yml"))
    .describe("source", "changelog source")
    .command(init)
    .command(add)
    .command(print)
    .command(cut)
    .command(schema)
    .command(upcoming)
    .command(latest)
    .strictCommands()
    .help()
    .parse();
