import fs from "fs-extra";
import yaml from "yaml";
import u from "@yanick/updeep-remeda";

const handler = async (config) => {
    if (!config.change)
        throw new Error("can't add a change without a description");

    const entry = {
        desc: config.change.join(" "),
    };

    if (config.ticket) entry.ticket = config.ticket;
    if (config.type) entry.type = config.type;

    config.consola.start(`adding '${entry.desc}' to the changelog`);

    config.add_to_next(entry);

    config.consola.success("done!");
};

export default {
    command: "add [change...]",
    desc: "add a change to the NEXT release",
    builder: (yargs) => {
        yargs
            .string("ticket")
            .describe("ticket", "ticket associated with the change")
            .string("type")
            .describe("type", "type of change")
            .middleware((argv) => {
                argv.add_to_next = async (entry) => {
                    const changelog = yaml.parse(await fs.readFile(argv.source, "utf-8"));

                    let next = changelog.releases.find(u.matches({ version: "NEXT" }));
                    if (!next) {
                        next = { version: "NEXT", changes: [] };
                        changelog.releases.unshift(next);
                    }

                    if (Object.keys(entry).length === 1) {
                        entry = entry.desc;
                    }

                    next.changes.push(entry);

                    return fs.writeFile(argv.source, yaml.stringify(changelog));
                };
            });
    },
    handler,
};
